pub struct HighEntropySecret {
secret: Zeroizing<Vec<u8>>,
}Expand description
A secret that is guaranteed to be high-entropy, and therefore safe to use as input keying material for a cheap KDF.
Fields
secret: Zeroizing<Vec<u8>>Implementations
Sourceimpl HighEntropySecret
impl HighEntropySecret
Sourcepub fn from<T: HighEntropySecretSource>(secret: T) -> Self
pub fn from<T: HighEntropySecretSource>(secret: T) -> Self
Constructs a HighEntropySecret from any HighEntropySecretSource, whose implementation
guarantees the provided bytes are high-entropy.
pub(crate) fn from_internal(secret: &[u8]) -> Self
Sourcepub fn make(desired_size: usize) -> Result<Self, HighEntropySecretError>
pub fn make(desired_size: usize) -> Result<Self, HighEntropySecretError>
Generates a new high-entropy secret of the desired size, using cryptographically secure random bytes. The generated bytes are high-entropy by construction.
desired_size should be at least 16 bytes to provide adequate security headroom.