pub struct SecretProtectedKeyEnvelope {
cose_encrypt: CoseEncrypt,
}Expand description
A secret-protected key envelope can seal a symmetric key, and protect it with a high-entropy secret of arbitrary length.
Unlike the crate::safe::PasswordProtectedKeyEnvelope, which is meant for low-entropy secrets such as PINs and uses a compute-hard or memory-hard KDF, this envelope assumes the secret is high-entropy and thus uses a cheap KDF (HKDF). The KDF salt is stored in the envelope and does not have to be provided.
Internally, HKDF-SHA256 is used as the KDF and AES-256-GCM is used to encrypt the key.
Fields
cose_encrypt: CoseEncryptImplementations
Sourceimpl SecretProtectedKeyEnvelope
impl SecretProtectedKeyEnvelope
Sourcepub fn seal<Ids: KeySlotIds>(
key_to_seal: Ids::Symmetric,
secret: &HighEntropySecret,
namespace: SecretProtectedKeyEnvelopeNamespace,
ctx: &KeyStoreContext<'_, Ids>,
) -> Result<Self, SecretProtectedKeyEnvelopeError>
pub fn seal<Ids: KeySlotIds>( key_to_seal: Ids::Symmetric, secret: &HighEntropySecret, namespace: SecretProtectedKeyEnvelopeNamespace, ctx: &KeyStoreContext<'_, Ids>, ) -> Result<Self, SecretProtectedKeyEnvelopeError>
Seals a symmetric key with a HighEntropySecret, using a random salt.
The secret is guaranteed to be high-entropy by the HighEntropySecret type, which the
cheap KDF used here relies on, since it cannot defend a low-entropy secret against
brute-forcing.
This should never fail, except for memory allocation error, when running the KDF.
Sourcefn seal_ref(
key_to_seal: &SymmetricCryptoKey,
secret: &HighEntropySecret,
namespace: SecretProtectedKeyEnvelopeNamespace,
) -> Result<Self, SecretProtectedKeyEnvelopeError>
fn seal_ref( key_to_seal: &SymmetricCryptoKey, secret: &HighEntropySecret, namespace: SecretProtectedKeyEnvelopeNamespace, ) -> Result<Self, SecretProtectedKeyEnvelopeError>
Seals a key reference with a secret. This function is not public since callers are expected to only work with key store references.
Sourcefn seal_ref_with_settings(
key_to_seal: &SymmetricCryptoKey,
secret: &HighEntropySecret,
hkdf_settings: &HkdfSettings,
namespace: SecretProtectedKeyEnvelopeNamespace,
) -> Result<Self, SecretProtectedKeyEnvelopeError>
fn seal_ref_with_settings( key_to_seal: &SymmetricCryptoKey, secret: &HighEntropySecret, hkdf_settings: &HkdfSettings, namespace: SecretProtectedKeyEnvelopeNamespace, ) -> Result<Self, SecretProtectedKeyEnvelopeError>
Seals a key reference with a secret and custom provided settings. This function is not public since callers are expected to only work with key store references.
Sourcepub fn unseal<Ids: KeySlotIds>(
&self,
secret: &HighEntropySecret,
namespace: SecretProtectedKeyEnvelopeNamespace,
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Result<Ids::Symmetric, SecretProtectedKeyEnvelopeError>
pub fn unseal<Ids: KeySlotIds>( &self, secret: &HighEntropySecret, namespace: SecretProtectedKeyEnvelopeNamespace, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<Ids::Symmetric, SecretProtectedKeyEnvelopeError>
Unseals a symmetric key from the secret-protected envelope, and stores it in the key store context.
fn unseal_ref( &self, secret: &HighEntropySecret, content_namespace: SecretProtectedKeyEnvelopeNamespace, ) -> Result<SymmetricCryptoKey, SecretProtectedKeyEnvelopeError>
Sourcepub fn reseal(
&self,
secret: &HighEntropySecret,
new_secret: &HighEntropySecret,
namespace: SecretProtectedKeyEnvelopeNamespace,
) -> Result<Self, SecretProtectedKeyEnvelopeError>
pub fn reseal( &self, secret: &HighEntropySecret, new_secret: &HighEntropySecret, namespace: SecretProtectedKeyEnvelopeNamespace, ) -> Result<Self, SecretProtectedKeyEnvelopeError>
Re-seals the key with a new salt, and a new secret
Sourcepub fn contained_key_id(
&self,
) -> Result<Option<KeyId>, SecretProtectedKeyEnvelopeError>
pub fn contained_key_id( &self, ) -> Result<Option<KeyId>, SecretProtectedKeyEnvelopeError>
Get the key ID of the contained key, if the key ID is stored on the envelope headers. Only COSE keys have a key ID, legacy keys do not.