pub struct SymmetricKeyEnvelope {
cose_encrypt0: CoseEncrypt0,
}Expand description
A symmetric key protected by another symmetric key
Fields
cose_encrypt0: CoseEncrypt0Implementations
Sourceimpl SymmetricKeyEnvelope
impl SymmetricKeyEnvelope
Sourcepub fn seal<Ids: KeyIds>(
key_to_seal: Ids::Symmetric,
sealing_key: Ids::Symmetric,
namespace: SymmetricKeyEnvelopeNamespace,
ctx: &KeyStoreContext<'_, Ids>,
) -> Result<Self, SymmetricKeyEnvelopeError>
pub fn seal<Ids: KeyIds>( key_to_seal: Ids::Symmetric, sealing_key: Ids::Symmetric, namespace: SymmetricKeyEnvelopeNamespace, ctx: &KeyStoreContext<'_, Ids>, ) -> Result<Self, SymmetricKeyEnvelopeError>
Seals a symmetric key with another symmetric key from the key store.
This should never fail, except for memory allocation errors.
Sourcepub fn unseal<Ids: KeyIds>(
&self,
wrapping_key: Ids::Symmetric,
namespace: SymmetricKeyEnvelopeNamespace,
ctx: &mut KeyStoreContext<'_, Ids>,
) -> Result<Ids::Symmetric, SymmetricKeyEnvelopeError>
pub fn unseal<Ids: KeyIds>( &self, wrapping_key: Ids::Symmetric, namespace: SymmetricKeyEnvelopeNamespace, ctx: &mut KeyStoreContext<'_, Ids>, ) -> Result<Ids::Symmetric, SymmetricKeyEnvelopeError>
Unseals a symmetric key from the envelope and stores it in the key store context.
Sourcepub fn contained_key_id(
&self,
) -> Result<Option<KeyId>, SymmetricKeyEnvelopeError>
pub fn contained_key_id( &self, ) -> Result<Option<KeyId>, SymmetricKeyEnvelopeError>
Get the key ID of the contained key.